"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyLint = void 0;
const fs_1 = require("fs");
const helpers_fn_1 = require("helpers-fn");
const lint_fn_1 = require("lint-fn");
function checkShouldContinue(result, label, debug) {
    if (debug)
        console.log(result, label);
    if (!result) {
        return true;
    }
    (0, helpers_fn_1.log)(`File is linted`, 'success');
    (0, helpers_fn_1.log)('sep');
    return false;
}
async function applyLint(fileName, debug = false) {
    if (!(0, fs_1.existsSync)(fileName))
        return (0, helpers_fn_1.log)(`${fileName} is deleted`, 'error');
    (0, helpers_fn_1.log)('sep');
    (0, helpers_fn_1.log)(`will lint ${fileName}`, 'info');
    const initialLintResult = await (0, lint_fn_1.lintFn)({
        filePath: fileName,
        debug
    });
    if (checkShouldContinue(initialLintResult, 'initial', debug))
        return;
    const lintResultWithOuter = await (0, lint_fn_1.lintFn)({
        filePath: fileName,
        prettierSpecialCase: 'outer',
        debug
    });
    if (checkShouldContinue(lintResultWithOuter, 'outer', debug))
        return;
    const lintResultWithLocal = await (0, lint_fn_1.lintFn)({
        filePath: fileName,
        prettierSpecialCase: 'local',
        forceTypescript: true,
        debug
    });
    if (checkShouldContinue(lintResultWithLocal, 'local', debug))
        return;
    (0, helpers_fn_1.log)(`File failed to be linted`, 'error');
    (0, helpers_fn_1.log)('sep');
}
exports.applyLint = applyLint;
